%----------------------------------------------------------------------------------
%
% Description :
% This function plots reference antenna pattern accoding to the contribution
% IEEE 802.15-06/474r0
%
% Programmed by R. Funada, H. Sawada  and K. faigusa (16-Oct-2006)
%----------------------------------------------------------------------------------

% Arguments:
% ant_type: Antenna pattern
%	1: Reference antenna model (15-06-0427-04-003c)
%	2: Gaussian-distributed antenna model
%	hpang:	half-power angle in deg
%	index:	figure index
%	TITLE:	figure title

function ant_ptn(ant_type, hpang,index,TITLE)

ij=1;
if ant_type == 1
	theta_ml=2.6*hpang;
	hpangrad=hpang*pi/180;
	G0 = 10*log10((1.6162./sin(hpangrad/2))^2);
	pp=-180:180;
	g=zeros(size(pp));
	for fai=-180:180
		if abs(fai)<=theta_ml/2
			G = G0 - 3.01 * (2*abs(fai)./hpang).^2;
		else
			G = -0.4111.*log(hpangrad)-10.597;
		end
		g(ij)=G-G0;
		ij=ij+1;
	end
else
	alfa = 4*log(2)./(hpang*pi/180).^2;
	for fai=-180:180
		g(ij)	= 10*log10(exp(-alfa.*abs(fai./180*pi).^2));
		ij=ij+1;
	end
end
if nargin > 1
	figure(index)
end



set(gca,'FontName','Arial')
set(gca,'FontSize',12)
plot(-180:180,g)
xlabel('\theta [deg]')
ylabel('D(\theta) [dB]')
if nargin > 2
	title(TITLE)
end